@@ -1,11 +1,10 @@
-from django.urls import include, path
+from django.urls import path
 from rest_framework import routers
 
 from . import views
 
 
 router = routers.SimpleRouter()
-router.register("phone-number", views.PhoneNumberViewSet)
 
 
 app_name = "auth"
@@ -14,5 +13,4 @@ urlpatterns = [
     path("logout/", views.LogoutView.as_view(), name="logout"),
     path("user/", views.CurrentUserView.as_view(), name="current-user"),
     path("users/<int:pk>/", views.BasicUserDetail.as_view(), name="user"),
-    path("", include(router.urls)),
-]
+] + router.urls
