@@ -1,7 +1,8 @@
-import factory
+import factory, factory.fuzzy
 import pytz
 
 from argus.auth.factories import SourceUserFactory
+from argus.util.datetime_utils import INFINITY_REPR
 from . import models
 
 
@@ -10,6 +11,9 @@ __all__ = [
     "SourceSystemFactory",
     "TagFactory",
     "IncidentFactory",
+    "IncidentTagRelationFactory",
+    "StatefulIncidentFactory",
+    "StatelessIncidentFactory",
 ]
 
 
@@ -46,9 +50,28 @@ class IncidentFactory(factory.django.DjangoModelFactory):
         model = models.Incident
 
     start_time = factory.Faker("date_time_between", start_date="-1d", end_date="+1d", tzinfo=pytz.UTC)
-    end_time = "infinity"
+    end_time = INFINITY_REPR
     source = factory.SubFactory(SourceSystemFactory)
     source_incident_id = factory.Faker("md5")
     details_url = factory.Faker("uri")
     description = factory.Faker("sentence")
+    level = factory.fuzzy.FuzzyChoice(models.Incident.LEVELS)  # Random valid level
     ticket_url = factory.Faker("uri")
+
+
+class StatefulIncidentFactory(IncidentFactory):
+    pass
+
+
+class StatelessIncidentFactory(IncidentFactory):
+    end_time = None
+
+
+class IncidentTagRelationFactory(factory.django.DjangoModelFactory):
+    class Meta:
+        model = models.IncidentTagRelation
+
+    tag = factory.SubFactory(TagFactory)
+    incident = factory.SubFactory(IncidentFactory)
+    added_by = factory.SubFactory(SourceUserFactory)
+    added_time = factory.Faker("date_time_between", start_date="-1d", end_date="+1d", tzinfo=pytz.UTC)
