@@ -15,27 +15,31 @@ Including another URLconf
 """
 from django.contrib import admin
 from django.urls import include, path, re_path
+
+from drf_spectacular.views import SpectacularAPIView, SpectacularSwaggerView
 from social_django.urls import extra
 
-from argus.auth.views import ObtainNewAuthToken
+from argus.auth.views import ObtainNewAuthToken, AuthMethodListView
 from argus.dataporten import views as dataporten_views
+from argus.notificationprofile.views import SchemaView
+from argus.site.views import error, MetadataView
 
 
-api_urls = [
-    path("auth/", include("argus.auth.urls")),
-    path("incidents/", include("argus.incident.urls")),
-    path("notificationprofiles/", include("argus.notificationprofile.urls")),
-    path("token-auth/", ObtainNewAuthToken.as_view(), name="api-token-auth"),
-]
-
 psa_urls = [
     # Overrides social_django's `complete` view
-    re_path(fr"^complete/(?P<backend>[^/]+){extra}$", dataporten_views.login_wrapper, name="complete"),
+    re_path(rf"^complete/(?P<backend>[^/]+){extra}$", dataporten_views.login_wrapper, name="complete"),
     path("", include("social_django.urls", namespace="social")),
 ]
 
 urlpatterns = [
+    # path(".error/", error),  # Only needed when testing error pages and error behavior
     path("admin/", admin.site.urls),
     path("oidc/", include(psa_urls)),
-    path("api/v1/", include(api_urls)),
+    path("login-methods/", AuthMethodListView.as_view(), name="login-methods"),
+    path("api/schema/", SpectacularAPIView.as_view(api_version="v1"), name="schema-v1-old"),
+    path("api/schema/swagger-ui/", SpectacularSwaggerView.as_view(url_name="schema-v1-old"), name="swagger-ui-v1-old"),
+    path("api/v1/", include(("argus.site.api_v1_urls", "api"), namespace="v1")),
+    path("api/v2/", include(("argus.site.api_v2_urls", "api"), namespace="v2")),
+    path("api/", MetadataView.as_view(), name="metadata"),
+    path("json-schema/<slug:slug>", SchemaView.as_view(), name="json-schema"),
 ]
